@@ -41,6 +41,7 @@
 #include "iptables.h"
 #include "meminfo.h"
 #include "vzfeatures.h"
+#include "io.h"
 
 static int _page_size;
 static int check_name(char *name);
@@ -126,6 +127,7 @@ static vps_config config[] = {
 {"NAME",	NULL, PARAM_NAME},
 
 {"FEATURES",	NULL, PARAM_FEATURES},
+{"IOPRIO",	NULL, PARAM_IOPRIO},
 {NULL		,NULL, -1}
 };
 
@@ -212,13 +214,14 @@ static struct option set_opt[] = {
 /*	name	*/
 {"name",	required_argument, NULL, PARAM_NAME},
 {"features",	required_argument, NULL, PARAM_FEATURES},
+{"ioprio",	required_argument, NULL, PARAM_IOPRIO},
 
 {NULL, 0, NULL, 0}
 };
 
 struct option *get_set_opt(void)
 {
-        return set_opt;
+	return set_opt;
 }
 
 const vps_config *conf_get_by_name(const vps_config *conf, const char *name)
@@ -277,7 +280,7 @@ static conf_struct *find_conf_line(list_head_t *head, char *name,
 	return NULL;
 }
 
-static int parse_setmode(vps_param *vps_p, char *val)
+static int parse_setmode(vps_param *vps_p, const char *val)
 {
 	if (!strcmp(val, "ignore"))
 		vps_p->opt.setmode = SET_IGNORE;
@@ -335,7 +338,7 @@ int conf_store_strlist(list_head_t *conf, char *name, list_head_t *val)
 	return 0;
 }
 
-int conf_store_str(list_head_t *conf, char *name, char *val)
+int conf_store_str(list_head_t *conf, char *name, const char *val)
 {
 	char *buf;
 	int len;
@@ -407,6 +410,32 @@ static void store_features(unsigned long long mask, unsigned long long known,
 	add_str_param(conf_h, buf);
 }
 
+int parse_ioprio(int id, io_param *io, char *val)
+{
+	if (parse_int(val, &io->ioprio))
+		return ERR_INVAL;
+	if (io->ioprio < VE_IOPRIO_MIN || io->ioprio > VE_IOPRIO_MAX)
+		return ERR_INVAL;
+	return 0;
+}
+
+static int store_ioprio(vps_param *old_p, vps_param *vps_p,
+				 vps_config *conf, list_head_t *conf_h)
+{
+	io_param *io_param;
+	char buf[20];
+
+	io_param = &vps_p->res.io;
+
+	if (conf->id != PARAM_IOPRIO || io_param->ioprio < 0)
+		return 0;
+
+	snprintf(buf, sizeof(buf), "%s=\"%d\"", conf->name, io_param->ioprio);
+	add_str_param(conf_h, buf);
+
+	return 0;
+}
+
 /******************** Iptables *************************/
 static int parse_iptables(env_param *env, char *val)
 {
@@ -579,7 +608,7 @@ int parse_twoul(const char *str, unsigned long *val)
 	return ret;
 }
 /******************** totalmem *************************/
-int parse_meminfo(meminfo_param *param, char *val)
+int parse_meminfo(meminfo_param *param, const char *val)
 {
 	int mode;
 	char mode_nm[32];
@@ -628,7 +657,7 @@ static int store_meminfo(vps_param *old_p, vps_param *vps_p, vps_config *conf,
 	return 0;
 }
 
-int parse_ub(vps_param *vps_p, char *val, int id, int divisor)
+int parse_ub(vps_param *vps_p, const char *val, int id, int divisor)
 {
 	int ret;
 	ub_res res;
@@ -699,8 +728,8 @@ static int parse_cap(char *str, cap_param *cap)
 	char cap_nm[128];
 	unsigned long *mask;
 
-        if ((token = strtok(str, "\t ")) == NULL)
-                return 0;
+	if ((token = strtok(str, "\t ")) == NULL)
+		return 0;
 	do {
 		if ((p = strrchr(token, ':')) == NULL) {
 			logger(-1, 0, "Invalid syntaxes in %s:"
@@ -712,7 +741,7 @@ static int parse_cap(char *str, cap_param *cap)
 		else if (!strcmp(p + 1, "on"))
 			mask = &cap->on;
 		else {
-                        logger(-1, 0, "Invalid syntaxes in %s:"
+			logger(-1, 0, "Invalid syntaxes in %s:"
 				" capname:on|off", token);
 			return ERR_INVAL;
 		}
@@ -724,9 +753,9 @@ static int parse_cap(char *str, cap_param *cap)
 			logger(-1, 0, "Capability %s is unknown", cap_nm);
 			return ERR_INVAL;
 		}
-        } while ((token = strtok(NULL, " ")));
+	} while ((token = strtok(NULL, " ")));
 
-        return 0;
+	return 0;
 }
 
 static int store_cap(vps_param *old_p, vps_param *vps_p, vps_config *conf,
@@ -753,18 +782,18 @@ static int store_cap(vps_param *old_p, vps_param *vps_p, vps_config *conf,
 
 int check_ip_dot(char *ip)
 {
-        int i;
-        char *str = ip;
+	int i;
+	char *str = ip;
 	char *p;
 
-        for (i = 0; i < 5; i++) {
-                if ((p = strchr(str, '.')) == NULL)
-                        break;
-                str = p + 1;
-        }
-        if (i != 3)
-                return VZ_BADIP;
-        return 0;
+	for (i = 0; i < 5; i++) {
+		if ((p = strchr(str, '.')) == NULL)
+			break;
+		str = p + 1;
+	}
+	if (i != 3)
+		return VZ_BADIP;
+	return 0;
 }
 
 static int parse_ip(vps_param *vps_p, char *val, int id)
@@ -835,17 +864,17 @@ static int store_ip(vps_param *old_p, vps_param *vps_p, vps_config *conf,
 
 static int check_netdev(const char *devname)
 {
-        int i, len;
+	int i, len;
 	const char *name;
 	static char *netdev_strict[] = {"venet", "tun", "tap", "lo", NULL};
 
-        for (i = 0; netdev_strict[i] != NULL; i++) {
+	for (i = 0; netdev_strict[i] != NULL; i++) {
 		name = netdev_strict[i];
 		len = strlen(name);
-                if (!strncmp(name, devname, len))
-                        return 1;
+		if (!strncmp(name, devname, len))
+			return 1;
 	}
-        return 0;
+	return 0;
 }
 
 int add_netdev(net_param *net, char *val)
@@ -1115,16 +1144,16 @@ static int parse_devnodes_str(const char *str, dev_res *dev)
 	char buf[64];
 	struct stat st;
 
-        if ((ch = strchr(str, ':')) == NULL)
-                return ERR_INVAL;
+	if ((ch = strchr(str, ':')) == NULL)
+		return ERR_INVAL;
 	ch++;
 	len = ch - str;
 	if (len > sizeof(dev->name))
 		return ERR_INVAL;
 	memset(dev, 0, sizeof(*dev));
-        snprintf(dev->name, len, "%s", str);
+	snprintf(dev->name, len, "%s", str);
 	snprintf(buf, sizeof(buf), "/dev/%s", dev->name);
-	if (stat(buf, &st)) {
+	if (lstat(buf, &st)) {
 		logger(-1, errno, "Incorrect device name %s", buf);
 		return ERR_INVAL;
 	}
@@ -1206,7 +1235,7 @@ static int store_misc(vps_param *old_p, vps_param *vps_p, vps_config *conf,
 	int ret;
 	
 	ret = 0;
-        switch (conf->id) {
+	switch (conf->id) {
 	case PARAM_ONBOOT:
 		ret = conf_store_yesno(conf_h, conf->name, vps_p->opt.onboot);
 		break;
@@ -1715,7 +1744,7 @@ static int parse_netif_cmd(envid_t veid, veth_param *veth, char *val)
 }
 
 static int store_name(vps_param *old_p, vps_param *vps_p, vps_config *conf,
-        list_head_t *conf_h)
+		list_head_t *conf_h)
 {
 	char buf[STR_SIZE];
 
@@ -1936,8 +1965,8 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 	case PARAM_CPUUNITS:
 		if (vps_p->res.cpu.units != NULL)
 			break;
-	        if (parse_ul(val, &uid))
-        	        return ERR_INVAL;
+		if (parse_ul(val, &uid))
+			return ERR_INVAL;
 		if (uid < MINCPUUNITS || uid > MAXCPUUNITS) 
 			return ERR_INVAL;
 		vps_p->res.cpu.units = malloc(sizeof(unsigned long));
@@ -1948,8 +1977,8 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 	case PARAM_CPUWEIGHT:
 		if (vps_p->res.cpu.weight != NULL)
 			break;
-	        if (parse_ul(val, &uid))
-        	        return ERR_INVAL;
+		if (parse_ul(val, &uid))
+			return ERR_INVAL;
 		vps_p->res.cpu.weight = malloc(sizeof(unsigned long));
 		if (vps_p->res.cpu.weight == NULL)
 			return ERR_NOMEM;
@@ -1958,14 +1987,14 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 	case PARAM_CPULIMIT:
 		if (vps_p->res.cpu.limit != NULL)
 			break;
-	        if (parse_cpulimit(&vps_p->res.cpu.limit, val))
-        	        return ERR_INVAL;
+		if (parse_cpulimit(&vps_p->res.cpu.limit, val))
+			return ERR_INVAL;
 		break;
 	case PARAM_VCPUS:
 		if (vps_p->res.cpu.vcpus != NULL)
 			break;
-	        if (parse_ul(val, &uid))
-        	        return ERR_INVAL;
+		if (parse_ul(val, &uid))
+			return ERR_INVAL;
 		vps_p->res.cpu.vcpus = malloc(sizeof(unsigned long));
 		if (vps_p->res.cpu.vcpus == NULL)
 			return ERR_NOMEM;
@@ -2042,6 +2071,10 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 	case PARAM_FEATURES:
 		ret = parse_features(&vps_p->res.env, val);
 		break;
+	case PARAM_IOPRIO:
+		if (parse_ioprio(id, &vps_p->res.io, val))
+			return ERR_INVAL;
+		break;
 	default:
 		logger(10, 0, "Not handled parameter %d %s", id, val);
 		break;
@@ -2069,6 +2102,7 @@ static int store(vps_param *old_p, vps_param *vps_p, list_head_t *conf_h)
 		store_meminfo(old_p, vps_p, conf, conf_h);
 		store_netif(old_p, vps_p, conf, conf_h);
 		store_name(old_p, vps_p, conf, conf_h);
+		store_ioprio(old_p, vps_p, conf, conf_h);
 	}
 	return 0;
 }
@@ -2093,7 +2127,7 @@ int vps_parse_config(envid_t veid, char *path, vps_param *vps_p,
 
 	if ((fp = fopen(path, "r")) == NULL) {
 		logger(-1, errno, "Unable to open %s", path);
-                return 1;
+		return 1;
 	}
 	if (!stat(path, &st))
 		len = st.st_size;
@@ -2154,7 +2188,7 @@ static int read_conf(char *fname, list_head_t *conf_h)
 	if (!stat_file(fname))
 		return 0;
 	if (!(fp = fopen(fname, "r"))) 
-                return -1;
+		return -1;
 	while (fgets(str, sizeof(str), fp)) {
 		add_str_param(conf_h, str);
 	}
@@ -2175,8 +2209,8 @@ static int write_conf(char *fname, list_head_t *head)
 		if ((fd = open(buf, O_CREAT|O_WRONLY|O_TRUNC, 0644)) < 0) {
 			logger(-1, errno, "Unable to create configuration"
 				" file %s", buf);
-	                return 1;
-        	}
+			return 1;
+		}
 	}
 	list_for_each(conf, head, list) {
 		if (conf->val == NULL)
@@ -2213,7 +2247,7 @@ static int vps_merge_conf(list_head_t *dst, list_head_t *src)
 
 	if (list_empty(src))
 		return 0;
-        list_for_each(conf, src, list) {
+	list_for_each(conf, src, list) {
 		if ((p = strchr(conf->val, '=')) == NULL)
 			 continue;
 		len = p - conf->val + 1;
@@ -2285,7 +2319,7 @@ int vps_remove_cfg_param(envid_t veid, char *path, char *name)
 }
 
 /********************************************************************/
-int vps_parse_opt(envid_t veid, vps_param *param, int opt, const char *rval,
+int vps_parse_opt(envid_t veid, vps_param *param, int opt, char *rval,
 	struct mod_action *action)
 {
 	int id, ret = 0;
@@ -2293,7 +2327,7 @@ int vps_parse_opt(envid_t veid, vps_param *param, int opt, const char *rval,
 	if (param == NULL)
 		return -1;
 	if ((id = opt_get_by_id(set_opt, opt)) != -1) {
-		ret = parse(veid, param, (char *)rval, id);
+		ret = parse(veid, param, rval, id);
 	} else if (action != NULL) {
 		ret = mod_parse(veid, action, NULL, opt, rval);
 	}
@@ -2327,6 +2361,7 @@ vps_param *init_vps_param()
 	list_head_init(&param->del_res.dev.dev);
 	list_head_init(&param->del_res.veth.dev);
 	param->res.meminfo.mode = -1;
+	param->res.io.ioprio = -1;
 
 	return param;
 }
@@ -2358,13 +2393,13 @@ int get_veid_by_name(char *name)
 
 static int check_name(char *name)
 {
-        char *p;
+	char *p;
 
-        for (p = name; *p != '\0'; p++) {
-                if (!isdigit(*p) && !isalpha(*p) && *p != '-' && *p != '_')
-                        return -1;
+	for (p = name; *p != '\0'; p++) {
+		if (!isdigit(*p) && !isalpha(*p) && *p != '-' && *p != '_')
+			return -1;
 	}
-        return 0;
+	return 0;
 }
 
 int set_name(int veid, char *new_name, char *old_name)
@@ -2681,6 +2716,10 @@ static void merge_name(name_param *dst, name_param *src)
 	MERGE_INT(veid);
 }
 
+static void merge_io(io_param *dst, io_param *src) {
+	MERGE_INT(ioprio);
+}
+
 static int merge_res(vps_res *dst, vps_res *src)
 {
 	merge_fs(&dst->fs, &src->fs);
@@ -2697,6 +2736,7 @@ static int merge_res(vps_res *dst, vps_res *src)
 	merge_meminfo(&dst->meminfo, &src->meminfo);
 	merge_veth(&dst->veth, &src->veth);
 	merge_name(&dst->name, &src->name);
+	merge_io(&dst->io, &src->io);
 	return 0;
 }
 
@@ -2705,7 +2745,7 @@ int merge_vps_param(vps_param *dst, vps_param *src)
 	merge_opt(&dst->opt, &src->opt);
 	merge_res(&dst->res, &src->res);
 
-        return 0;
+	return 0;
 }
 
 int merge_global_param(vps_param *dst, vps_param *src)
