@@ -184,8 +184,8 @@ int none_sort_fn(const void *val1, const void *val2)
 
 int laverage_sort_fn(const void *val1, const void *val2)
 {
-	struct Cla *la1 = ((struct Cveinfo *)val1)->la;
-	struct Cla *la2 = ((struct Cveinfo *)val2)->la;
+	struct Cla *la1 = ((const struct Cveinfo *)val1)->la;
+	struct Cla *la2 = ((const struct Cveinfo *)val2)->la;
 	int res;
 
 	if ((res = check_empty_param(la1, la2)) == 2)
@@ -202,14 +202,17 @@ int laverage_sort_fn(const void *val1, const void *val2)
 int id_sort_fn(const void *val1, const void *val2)
 {
 	int ret;
-	ret = (((struct Cveinfo*)val1)->veid > ((struct Cveinfo*)val2)->veid);
+	ret = (((const struct Cveinfo*)val1)->veid > 
+		((const struct Cveinfo*)val2)->veid);
 	return ret;
 }
 
 int status_sort_fn(const void *val1, const void *val2)
 {
 	int res;
-	res = ((struct Cveinfo*)val1)->status - ((struct Cveinfo*)val2)->status;	if (!res)
+	res = ((const struct Cveinfo*)val1)->status - 
+		((const struct Cveinfo*)val2)->status;
+	if (!res)
 		res = id_sort_fn(val1, val2);
 	return res;
 }
@@ -217,8 +220,8 @@ int status_sort_fn(const void *val1, const void *val2)
 #define SORT_STR_FN(fn, name)	 					\
 int fn(const void *val1, const void *val2)				\
 {									\
-	const char *h1 = ((struct Cveinfo*)val1)->name;			\
-	const char *h2 = ((struct Cveinfo*)val2)->name;			\
+	const char *h1 = ((const struct Cveinfo*)val1)->name;		\
+	const char *h2 = ((const struct Cveinfo*)val2)->name;		\
 	int ret;							\
 	if ((ret = check_empty_param(h1, h2)) == 2)			\
 		ret = strcmp(h1, h2);					\
@@ -232,8 +235,8 @@ SORT_STR_FN(ip_sort_fn, ip)
 #define SORT_UL_RES(fn, type, res, name, index)				\
 int fn(const void *val1, const void *val2)				\
 {									\
-	struct type *r1 = ((struct Cveinfo *)val1)->res;		\
-	struct type *r2 = ((struct Cveinfo *)val2)->res;		\
+	struct type *r1 = ((const struct Cveinfo *)val1)->res;		\
+	struct type *r2 = ((const struct Cveinfo *)val2)->res;		\
 	int ret;							\
 	if ((ret = check_empty_param(r1, r2)) == 2)			\
 		ret = r1->name[index] > r2->name[index];		\
@@ -596,7 +599,7 @@ void usage()
 {
 	fprintf(stderr, "Usage: vzlist [-a] [-o name[,name...]] [-s {name|-name}] [-h <pattern>] [-N <pattern>]\n");
 	fprintf(stderr, "\t\t[-H] [-S] [veid [veid ...]|-1]\n");
-	fprintf(stderr, "       vzlist -L\n\n");
+	fprintf(stderr, "	vzlist -L\n\n");
 	fprintf(stderr, "\t--all -a\t list of all VEs\n");
 	fprintf(stderr, "\t--output -o\t output only specified parameters\n");
 	fprintf(stderr, "\t--hostname -h\t hostname search pattern\n");
@@ -612,12 +615,12 @@ void usage()
 
 int id_search_fn(const void* val1, const void* val2)
 {
-	return (*(int *)val1 - ((struct Cveinfo*)val2)->veid);
+	return (*(const int *)val1 - ((const struct Cveinfo*)val2)->veid);
 }
 
 int veid_search_fn(const void* val1, const void* val2)
 {
-	return (*(int *)val1 - *(int *)val2);
+	return (*(const int *)val1 - *(const int *)val2);
 }
 
 void print_hdr()
@@ -804,7 +807,7 @@ char *parse_var(char *var)
 #define MERGE_QUOTA(name, quota, dq)				\
 do {								\
 	if (dq.name != NULL) {					\
-		quota->name[1] = dq.name[0];     		\
+		quota->name[1] = dq.name[0];			\
 		quota->name[2] = dq.name[1];			\
 	}							\
 } while(0);							
@@ -818,7 +821,7 @@ void merge_conf(struct Cveinfo *ve, vps_res *res)
 do {								\
 	if (res == NULL || res->ub.name == NULL) 		\
 		break;						\
-	ubc->name[2] = res->ub.name[0];     			\
+	ubc->name[2] = res->ub.name[0];				\
 	ubc->name[3] = res->ub.name[1];				\
 } while(0);							
 
@@ -932,10 +935,10 @@ int check_veid_restr(int veid)
 do {						\
 	if (!strcmp(str, #name)) {		\
 		ubc->name[0] = held;		\
-		ubc->name[1] = maxheld;     	\
-		ubc->name[2] = barrier;     	\
-		ubc->name[3] = limit;     	\
-		ubc->name[4] = failcnt;     	\
+		ubc->name[1] = maxheld;		\
+		ubc->name[2] = barrier;		\
+		ubc->name[3] = limit;		\
+		ubc->name[4] = failcnt;		\
 	}					\
 } while(0);					\
 
@@ -1343,9 +1346,9 @@ int get_ve_la(int veid)
 	statctl.cpustat = &stat;
 	if (ioctl(vzctlfd, VZCTL_GET_CPU_STAT, &statctl) != 0)
 		return 1;
-        la.la[0] = stat.avenrun[0].val_int + (stat.avenrun[0].val_frac * 0.01);
-        la.la[1] = stat.avenrun[1].val_int + (stat.avenrun[1].val_frac * 0.01);
-        la.la[2] = stat.avenrun[2].val_int + (stat.avenrun[2].val_frac * 0.01);
+	la.la[0] = stat.avenrun[0].val_int + (stat.avenrun[0].val_frac * 0.01);
+	la.la[1] = stat.avenrun[1].val_int + (stat.avenrun[1].val_frac * 0.01);
+	la.la[2] = stat.avenrun[2].val_int + (stat.avenrun[2].val_frac * 0.01);
 
 	update_la(veid, &la);
 	return 0;
@@ -1581,7 +1584,7 @@ static struct option list_options[] =
 	{"no-header",	no_argument, NULL, 'H'},
 	{"stopped",	no_argument, NULL, 'S'},
 	{"all",		no_argument, NULL, 'a'},
-	{"name",        no_argument, NULL, 'n'},
+	{"name",	no_argument, NULL, 'n'},
 	{"name_filter", required_argument, NULL, 'N'},
 	{"hostname",	required_argument, NULL, 'h'},
 	{"output",	required_argument, NULL, 'o'},
@@ -1606,7 +1609,7 @@ int main(int argc, char **argv)
 			break;
 		
 		switch(c) {
-		case 'S'        :
+		case 'S'	:
 			only_stopped_ve = 1;
 			break;
 		case 'H'	:
@@ -1615,7 +1618,7 @@ int main(int argc, char **argv)
 		case 'L'	:
 			print_names();
 			return 0;
-		case 'a'        :
+		case 'a'	:
 			all_ve = 1;
 			break;
 		case 'h'	:
@@ -1649,7 +1652,7 @@ int main(int argc, char **argv)
 		default		:
 			usage();
 			return 1;
-                }
+		}
 	}
 	if (optind < argc) {
 		while (optind < argc) {
@@ -1669,7 +1672,7 @@ int main(int argc, char **argv)
 	if (build_field_order(f_order)) 
 		return 1;
 	if (getuid()) {
-	        fprintf(stderr, "This program can only be run under root.\n");
+		fprintf(stderr, "This program can only be run under root.\n");
 		return 1;
 	}
 	if ((ret = collect()))
